# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2017-02-12 17:48
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('plugs_media', '0008_mediacontenttype'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='media',
            name='content_type',
        ),
        migrations.AddField(
            model_name='media',
            name='media_content_type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='plugs_media.MediaContentType'),
        ),
    ]
