# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2017-01-07 19:57
from __future__ import unicode_literals

import datetime
from django.db import migrations, models
from django.utils.timezone import utc


class Migration(migrations.Migration):

    dependencies = [
        ('plugs_media', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='media',
            name='created',
            field=models.DateTimeField(auto_now_add=True, default=datetime.datetime(2017, 1, 7, 19, 57, 23, 177843, tzinfo=utc)),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='media',
            name='file',
            field=models.FileField(default='', max_length=255, upload_to='%Y/%m/%d/'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='media',
            name='name',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='media',
            name='updated',
            field=models.DateTimeField(auto_now=True, default=datetime.datetime(2017, 1, 7, 19, 57, 47, 274570, tzinfo=utc)),
            preserve_default=False,
        ),
    ]
