# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2017-08-14 15:27
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('plugs_media', '0009_auto_20170212_1748'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='media',
            name='media_content_type',
        ),
        migrations.RemoveField(
            model_name='media',
            name='object_id',
        ),
        migrations.DeleteModel(
            name='MediaContentType',
        ),
    ]
